@@ -3,19 +3,68 @@ package XS::JIT;
 use 5.008003;
 use strict;
 use warnings;
+use File::Spec;
+use Config;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load('XS::JIT', $VERSION);
 
+# Find the XS::JIT installation directory (where headers and libs are)
+sub _find_xs_jit_dir {
+    my @search_paths = (
+        # Standard installation locations
+        File::Spec->catdir($Config{installsitearch}, 'auto', 'XS', 'JIT'),
+        File::Spec->catdir($Config{installvendorarch} || '', 'auto', 'XS', 'JIT'),
+        File::Spec->catdir($Config{installarchlib}, 'auto', 'XS', 'JIT'),
+        # Local lib (for local::lib users)
+        (exists $ENV{PERL_LOCAL_LIB_ROOT}
+            ? File::Spec->catdir($ENV{PERL_LOCAL_LIB_ROOT}, 'lib', 'perl5', $Config{archname}, 'auto', 'XS', 'JIT')
+            : ()),
+        # Relative to this module (for uninstalled/development use)
+        File::Spec->catdir(File::Spec->rel2abs(__FILE__), '..', '..', '..', '..', 'lib', 'XS', 'JIT'),
+    );
+
+    for my $dir (@search_paths) {
+        next unless defined $dir && length $dir;
+        my $header = File::Spec->catfile($dir, 'xs_jit.h');
+        return $dir if -f $header;
+    }
+    return undef;
+}
+
+sub inc_dir {
+    my $dir = _find_xs_jit_dir();
+    die "Cannot find XS::JIT installation directory with xs_jit.h" unless $dir;
+    return $dir;
+}
+
+sub cflags {
+    my $dir = inc_dir();
+    return "-I$dir";
+}
+
+sub libs {
+    my $dir = inc_dir();
+    # LIBS expects -L and -l format
+    return "-L$dir -lxs_jit";
+}
+
+sub static_libs {
+    my $dir = inc_dir();
+    my $lib = File::Spec->catfile($dir, 'libxs_jit.a');
+    return $lib if -f $lib;
+    return undef;
+}
+
 =head1 NAME
 
 XS::JIT - Lightweight JIT compiler for XS code
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -168,6 +217,44 @@ A hashref mapping Perl function names to C function names.
 
 Returns the complete generated C code as a string.
 
+=head2 inc_dir
+
+    my $dir = XS::JIT->inc_dir();
+
+Returns the directory containing the XS::JIT header file (xs_jit.h).
+This is useful for modules that want to use the XS::JIT C API.
+
+Dies if the installation directory cannot be found.
+
+=head2 cflags
+
+    my $cflags = XS::JIT->cflags();
+
+Returns compiler flags needed to compile code that uses the XS::JIT C API.
+Currently returns C<-I/path/to/xs_jit.h>.
+
+=head2 libs
+
+    my $libs = XS::JIT->libs();
+
+Returns linker flags needed for XS::JIT in the format C<-L/path -lxs_jit>.
+
+=head2 static_libs
+
+    my $lib_path = XS::JIT->static_libs();
+
+Returns the full path to the static library C<libxs_jit.a>, or C<undef> if
+not found. Useful for build systems that prefer explicit static linking.
+
+Use both C<cflags> and C<libs> in your Makefile.PL:
+
+    use XS::JIT;
+    WriteMakefile(
+        ...
+        INC  => XS::JIT->cflags(),
+        LIBS => [XS::JIT->libs()],
+    );
+
 =head1 WRITING C FUNCTIONS
 
 XS::JIT supports two styles of C functions: wrapper-style functions that
@@ -279,10 +366,18 @@ Example usage:
 Set C<is_xs_native> to 1 when your functions use C<XS_EUPXS()>, C<dXSARGS>,
 and C<XSRETURN()> directly. This creates simple aliases instead of wrappers.
 
-The header file is installed to your Perl's site architecture directory
-and can be found using:
+The header file location can be found programmatically:
 
-    perl -MConfig -e 'print "$Config{installsitearch}/auto/XS/JIT\n"'
+    use XS::JIT;
+    print XS::JIT->inc_dir(), "\n";
+
+Or use the C<cflags> method in your Makefile.PL:
+
+    use XS::JIT;
+    WriteMakefile(
+        ...
+        INC => XS::JIT->cflags(),
+    );
 
 =head1 CONVENIENCE MACROS
 
